"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
const compass_components_1 = require("@mongodb-js/compass-components");
const url_options_1 = require("../../../utils/url-options");
const optionSelectStyles = (0, compass_components_1.css)({
    width: compass_components_1.spacing[5] * 9,
});
const optionNameCellStyles = (0, compass_components_1.css)({
    width: compass_components_1.spacing[5] * 9,
});
const optionValueCellStyles = (0, compass_components_1.css)({});
const optionValueCellContentStyles = (0, compass_components_1.css)({
    display: 'flex',
    flexDirection: 'row',
    justifyContent: 'flex-start',
    alignItems: 'center',
});
const valueInputStyles = (0, compass_components_1.css)({
    maxWidth: compass_components_1.spacing[7],
});
const deleteOptionButtonStyle = (0, compass_components_1.css)({
    marginLeft: compass_components_1.spacing[2],
});
function appendEmptyOption(urlOptions) {
    if (!urlOptions.length || urlOptions[urlOptions.length - 1].name) {
        return [...urlOptions, { name: undefined, value: undefined }];
    }
    return urlOptions;
}
function getUrlOptions(connectionStringUrl) {
    let opts = [];
    const urlOptions = [];
    const searchParams = connectionStringUrl.typedSearchParams();
    url_options_1.editableUrlOptions.forEach(({ values }) => (opts = opts.concat(values)));
    searchParams.forEach((value, name) => {
        if (opts.includes(name)) {
            urlOptions.push({
                value: value,
                name: name,
            });
        }
    });
    return urlOptions;
}
function UrlOptionsTable({ updateConnectionFormField, connectionStringUrl, }) {
    const [options, setOptions] = react_1.default.useState([]);
    (0, react_1.useEffect)(() => {
        const options = appendEmptyOption(getUrlOptions(connectionStringUrl));
        setOptions(options);
    }, [connectionStringUrl]);
    const updateUrlOption = (currentName, name, value) => {
        const indexOfUpdatedOption = options.findIndex((option) => option.name === currentName);
        const option = {
            name,
            value,
        };
        const newOptions = [...options];
        newOptions[indexOfUpdatedOption] = option;
        setOptions(appendEmptyOption(newOptions));
        if (name) {
            updateConnectionFormField({
                type: 'update-search-param',
                currentKey: currentName !== null && currentName !== void 0 ? currentName : name,
                newKey: currentName === name ? undefined : name,
                value: value !== null && value !== void 0 ? value : '',
            });
        }
    };
    const deleteUrlOption = (name) => {
        if (!name) {
            return;
        }
        const indexOfDeletedOption = options.findIndex((option) => option.name === name);
        const newOptions = [...options];
        newOptions.splice(indexOfDeletedOption, 1);
        setOptions(appendEmptyOption(newOptions));
        updateConnectionFormField({
            type: 'delete-search-param',
            key: name,
        });
    };
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(compass_components_1.Table, { "data-testid": "url-options-table", data: options, columns: [
                react_1.default.createElement(compass_components_1.TableHeader, { key: 'name', label: "Key" }),
                react_1.default.createElement(compass_components_1.TableHeader, { key: 'value', label: "Value" }),
            ] }, ({ datum }) => {
            var _a, _b;
            return (react_1.default.createElement(compass_components_1.Row, { key: datum.name, "data-testid": datum.name ? `${datum.name}-table-row` : 'new-option-table-row' },
                react_1.default.createElement(compass_components_1.Cell, { className: optionNameCellStyles },
                    react_1.default.createElement(compass_components_1.Select, { className: optionSelectStyles, placeholder: "Select key", name: "name", "aria-labelledby": datum.name ? `${datum.name} select` : 'new option select', onChange: (name, event) => {
                            event.preventDefault();
                            updateUrlOption(datum.name, name, datum.value);
                        }, allowDeselect: false, value: (_a = datum.name) !== null && _a !== void 0 ? _a : '' }, url_options_1.editableUrlOptions.map(({ title, values }) => (react_1.default.createElement(compass_components_1.OptionGroup, { key: title, label: title }, values.map((value) => (react_1.default.createElement(compass_components_1.Option, { key: value, value: value, disabled: connectionStringUrl.searchParams.has(value) &&
                            datum.name !== value }, value)))))))),
                react_1.default.createElement(compass_components_1.Cell, { className: optionValueCellStyles },
                    react_1.default.createElement("div", { className: optionValueCellContentStyles },
                        react_1.default.createElement(compass_components_1.TextInput, { onChange: (event) => {
                                event.preventDefault();
                                updateUrlOption(datum.name, datum.name, event.target.value);
                            }, "data-testid": datum.name
                                ? `${datum.name}-input-field`
                                : 'new-option-input-field', spellCheck: false, type: 'text', placeholder: 'Value', "aria-labelledby": "Enter value", value: datum.value, className: valueInputStyles }),
                        datum.name ? (react_1.default.createElement(compass_components_1.IconButton, { "data-testid": datum.name
                                ? `${datum.name}-delete-button`
                                : 'new-option-delete-button', "aria-label": `Delete option: ${(_b = datum.name) !== null && _b !== void 0 ? _b : ''}`, onClick: () => deleteUrlOption(datum.name), className: deleteOptionButtonStyle },
                            react_1.default.createElement(compass_components_1.Icon, { glyph: "X" }))) : ('')))));
        })));
}
exports.default = UrlOptionsTable;
//# sourceMappingURL=url-options-table.js.map