"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
const compass_components_1 = require("@mongodb-js/compass-components");
const mongodb_1 = require("mongodb");
const form_field_container_1 = __importDefault(require("../../form-field-container"));
const validation_1 = require("../../../utils/validation");
const connection_string_helpers_1 = require("../../../utils/connection-string-helpers");
const authSourceLabelStyles = (0, compass_components_1.css)({
    padding: 0,
    margin: 0,
    flexGrow: 1,
});
const infoButtonStyles = (0, compass_components_1.css)({
    verticalAlign: 'middle',
    marginTop: -compass_components_1.spacing[1],
});
const defaultAuthMechanismOptions = [
    {
        title: 'Default',
        value: mongodb_1.AuthMechanism.MONGODB_DEFAULT,
    },
    {
        title: 'SCRAM-SHA-1',
        value: mongodb_1.AuthMechanism.MONGODB_SCRAM_SHA1,
    },
    {
        title: 'SCRAM-SHA-256',
        value: mongodb_1.AuthMechanism.MONGODB_SCRAM_SHA256,
    },
];
function AuthenticationDefault({ errors, connectionStringUrl, updateConnectionFormField, }) {
    var _a, _b, _c;
    const password = (0, connection_string_helpers_1.getConnectionStringPassword)(connectionStringUrl);
    const username = (0, connection_string_helpers_1.getConnectionStringUsername)(connectionStringUrl);
    const selectedAuthMechanism = ((_a = connectionStringUrl.searchParams.get('authMechanism')) !== null && _a !== void 0 ? _a : '').toUpperCase();
    const selectedAuthTab = (_b = defaultAuthMechanismOptions.find(({ value }) => value === selectedAuthMechanism)) !== null && _b !== void 0 ? _b : defaultAuthMechanismOptions[0];
    const onAuthMechanismSelected = (0, react_1.useCallback)((event) => {
        event.preventDefault();
        updateConnectionFormField({
            type: 'update-search-param',
            currentKey: 'authMechanism',
            value: event.target.value,
        });
    }, [updateConnectionFormField]);
    const usernameError = (0, validation_1.errorMessageByFieldName)(errors, 'username');
    const passwordError = (0, validation_1.errorMessageByFieldName)(errors, 'password');
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(form_field_container_1.default, null,
            react_1.default.createElement(compass_components_1.TextInput, { onChange: ({ target: { value }, }) => {
                    updateConnectionFormField({
                        type: 'update-username',
                        username: value,
                    });
                }, label: "Username", errorMessage: usernameError, state: usernameError ? 'error' : undefined, value: username || '' })),
        react_1.default.createElement(form_field_container_1.default, null,
            react_1.default.createElement(compass_components_1.TextInput, { onChange: ({ target: { value }, }) => {
                    updateConnectionFormField({
                        type: 'update-password',
                        password: value,
                    });
                }, label: "Password", type: "password", value: password || '', errorMessage: passwordError, state: passwordError ? 'error' : undefined })),
        react_1.default.createElement(form_field_container_1.default, null,
            react_1.default.createElement(compass_components_1.Label, { className: authSourceLabelStyles, htmlFor: "authSourceInput", id: "authSourceLabel" },
                "Authentication Database",
                react_1.default.createElement(compass_components_1.IconButton, { className: infoButtonStyles, "aria-label": "Authentication Database Documentation", href: "https://docs.mongodb.com/manual/reference/connection-string/#mongodb-urioption-urioption.authSource", target: "_blank" },
                    react_1.default.createElement(compass_components_1.Icon, { glyph: "InfoWithCircle", size: "small" }))),
            react_1.default.createElement(compass_components_1.TextInput, { onChange: ({ target: { value }, }) => {
                    if (value === '') {
                        updateConnectionFormField({
                            type: 'delete-search-param',
                            key: 'authSource',
                        });
                        return;
                    }
                    updateConnectionFormField({
                        type: 'update-search-param',
                        currentKey: 'authSource',
                        value,
                    });
                }, id: "authSourceInput", "aria-labelledby": "authSourceLabel", value: (_c = connectionStringUrl.searchParams.get('authSource')) !== null && _c !== void 0 ? _c : '', optional: true })),
        react_1.default.createElement(form_field_container_1.default, null,
            react_1.default.createElement(compass_components_1.Label, { htmlFor: "authentication-mechanism-radio-box-group" }, "Authentication Mechanism"),
            react_1.default.createElement(compass_components_1.RadioBoxGroup, { onChange: onAuthMechanismSelected, id: "authentication-mechanism-radio-box-group", size: "default", value: selectedAuthTab.value }, defaultAuthMechanismOptions.map(({ title, value }) => {
                return (react_1.default.createElement(compass_components_1.RadioBox, { "data-testid": `${value}-tab-button`, checked: selectedAuthTab.value === value, value: value, key: value, size: "default" }, title));
            })))));
}
exports.default = AuthenticationDefault;
//# sourceMappingURL=authentication-default.js.map