"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GSSAPI_SERVICE_REALM_LABEL = exports.GSSAPI_CANONICALIZE_HOST_NAME_LABEL = exports.GSSAPI_SERVICE_NAME_LABEL = exports.GSSAPI_PRINCIPAL_NAME_LABEL = void 0;
const react_1 = __importDefault(require("react"));
const compass_components_1 = require("@mongodb-js/compass-components");
const form_field_container_1 = __importDefault(require("../../form-field-container"));
const validation_1 = require("../../../utils/validation");
const connection_string_helpers_1 = require("../../../utils/connection-string-helpers");
exports.GSSAPI_PRINCIPAL_NAME_LABEL = 'Principal';
exports.GSSAPI_SERVICE_NAME_LABEL = 'Service Name';
exports.GSSAPI_CANONICALIZE_HOST_NAME_LABEL = 'Canonicalize Host Name';
exports.GSSAPI_SERVICE_REALM_LABEL = 'Service Realm';
function AuthenticationGSSAPI({ errors, connectionStringUrl, updateConnectionFormField, }) {
    const kerberosPrincipalError = (0, validation_1.errorMessageByFieldName)(errors, 'kerberosPrincipal');
    const principal = (0, connection_string_helpers_1.getConnectionStringUsername)(connectionStringUrl);
    const authMechanismProperties = (0, connection_string_helpers_1.parseAuthMechanismProperties)(connectionStringUrl);
    const serviceName = authMechanismProperties.get('SERVICE_NAME');
    const serviceRealm = authMechanismProperties.get('SERVICE_REALM');
    const canonicalizeHostname = authMechanismProperties.get('CANONICALIZE_HOST_NAME');
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(form_field_container_1.default, null,
            react_1.default.createElement(compass_components_1.TextInput, { onChange: ({ target: { value }, }) => {
                    updateConnectionFormField({
                        type: 'update-username',
                        username: value,
                    });
                }, label: exports.GSSAPI_PRINCIPAL_NAME_LABEL, errorMessage: kerberosPrincipalError, state: kerberosPrincipalError ? 'error' : undefined, value: principal || '' })),
        react_1.default.createElement(form_field_container_1.default, null,
            react_1.default.createElement(compass_components_1.TextInput, { onChange: ({ target: { value }, }) => {
                    updateConnectionFormField({
                        type: 'update-auth-mechanism-property',
                        key: 'SERVICE_NAME',
                        value: value,
                    });
                }, label: exports.GSSAPI_SERVICE_NAME_LABEL, value: serviceName || '' })),
        react_1.default.createElement(form_field_container_1.default, null,
            react_1.default.createElement(compass_components_1.Checkbox, { onChange: (event) => {
                    updateConnectionFormField({
                        type: 'update-auth-mechanism-property',
                        key: 'CANONICALIZE_HOST_NAME',
                        value: event.target.checked ? 'true' : '',
                    });
                }, label: exports.GSSAPI_CANONICALIZE_HOST_NAME_LABEL, checked: canonicalizeHostname === 'true', bold: false })),
        react_1.default.createElement(form_field_container_1.default, null,
            react_1.default.createElement(compass_components_1.TextInput, { onChange: ({ target: { value }, }) => {
                    updateConnectionFormField({
                        type: 'update-auth-mechanism-property',
                        key: 'SERVICE_REALM',
                        value: value,
                    });
                }, label: exports.GSSAPI_SERVICE_REALM_LABEL, value: serviceRealm || '' }))));
}
exports.default = AuthenticationGSSAPI;
//# sourceMappingURL=authentication-gssapi.js.map