"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
const compass_components_1 = require("@mongodb-js/compass-components");
const mongodb_1 = require("mongodb");
const authentication_default_1 = __importDefault(require("./authentication-default"));
const authentication_x509_1 = __importDefault(require("./authentication-x509"));
const authentication_gssapi_1 = __importDefault(require("./authentication-gssapi"));
const authentication_plain_1 = __importDefault(require("./authentication-plain"));
const authentication_aws_1 = __importDefault(require("./authentication-aws"));
const options = [
    {
        title: 'None',
        id: 'AUTH_NONE',
        component: function None() {
            return react_1.default.createElement(react_1.default.Fragment, null);
        },
    },
    {
        title: 'Username/Password',
        id: mongodb_1.AuthMechanism.MONGODB_DEFAULT,
        component: authentication_default_1.default,
    },
    {
        title: 'X.509',
        id: mongodb_1.AuthMechanism.MONGODB_X509,
        component: authentication_x509_1.default,
    },
    {
        title: 'Kerberos',
        id: mongodb_1.AuthMechanism.MONGODB_GSSAPI,
        component: authentication_gssapi_1.default,
    },
    {
        title: 'LDAP',
        id: mongodb_1.AuthMechanism.MONGODB_PLAIN,
        component: authentication_plain_1.default,
    },
    {
        title: 'AWS IAM',
        id: mongodb_1.AuthMechanism.MONGODB_AWS,
        component: authentication_aws_1.default,
    },
];
const containerStyles = (0, compass_components_1.css)({
    marginTop: compass_components_1.spacing[3],
});
const contentStyles = (0, compass_components_1.css)({
    marginTop: compass_components_1.spacing[3],
    width: '50%',
});
function getSelectedAuthTabForConnectionString(connectionStringUrl) {
    const authMechanismString = (connectionStringUrl.searchParams.get('authMechanism') || '').toUpperCase();
    const hasPasswordOrUsername = connectionStringUrl.password || connectionStringUrl.username;
    if (!authMechanismString && hasPasswordOrUsername) {
        return mongodb_1.AuthMechanism.MONGODB_DEFAULT;
    }
    const matchingTab = options.find(({ id }) => id === authMechanismString);
    if (matchingTab) {
        return matchingTab.id;
    }
    switch (authMechanismString) {
        case mongodb_1.AuthMechanism.MONGODB_DEFAULT:
        case mongodb_1.AuthMechanism.MONGODB_SCRAM_SHA1:
        case mongodb_1.AuthMechanism.MONGODB_SCRAM_SHA256:
        case mongodb_1.AuthMechanism.MONGODB_CR:
            return mongodb_1.AuthMechanism.MONGODB_DEFAULT;
        default:
            return 'AUTH_NONE';
    }
}
function AuthenticationTab({ errors, updateConnectionFormField, connectionStringUrl, }) {
    const selectedAuthTabId = getSelectedAuthTabForConnectionString(connectionStringUrl);
    const selectedAuthTab = options.find(({ id }) => id === selectedAuthTabId) || options[0];
    const optionSelected = (0, react_1.useCallback)((event) => {
        event.preventDefault();
        return updateConnectionFormField({
            type: 'update-auth-mechanism',
            authMechanism: event.target.value === 'AUTH_NONE'
                ? null
                : event.target.value,
        });
    }, [updateConnectionFormField]);
    const AuthOptionContent = selectedAuthTab.component;
    return (react_1.default.createElement("div", { className: containerStyles },
        react_1.default.createElement(compass_components_1.Label, { htmlFor: "authentication-method-radio-box-group" }, "Authentication Method"),
        react_1.default.createElement(compass_components_1.RadioBoxGroup, { onChange: optionSelected, className: "radio-box-group-style", value: selectedAuthTab.id }, options.map(({ title, id }) => {
            return (react_1.default.createElement(compass_components_1.RadioBox, { "data-testid": `${id}-tab-button`, checked: selectedAuthTab.id === id, value: id, key: id }, title));
        })),
        react_1.default.createElement("div", { className: contentStyles, "data-testid": `${selectedAuthTab.id}-tab-content` },
            react_1.default.createElement(AuthOptionContent, { errors: errors, connectionStringUrl: connectionStringUrl, updateConnectionFormField: updateConnectionFormField }))));
}
exports.default = AuthenticationTab;
//# sourceMappingURL=authentication-tab.js.map