"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
const compass_components_1 = require("@mongodb-js/compass-components");
const ssh_tunnel_identity_1 = __importDefault(require("./ssh-tunnel-identity"));
const ssh_tunnel_password_1 = __importDefault(require("./ssh-tunnel-password"));
const socks_1 = __importDefault(require("./socks"));
const options = [
    {
        title: 'None',
        id: 'none',
        type: 'none',
        component: function None() {
            return react_1.default.createElement(react_1.default.Fragment, null);
        },
    },
    {
        title: 'SSH with Password',
        id: 'password',
        type: 'ssh-password',
        component: ssh_tunnel_password_1.default,
    },
    {
        title: 'SSH with Identity File',
        id: 'identity',
        type: 'ssh-identity',
        component: ssh_tunnel_identity_1.default,
    },
    {
        title: 'Socks5',
        id: 'socks',
        type: 'socks',
        component: socks_1.default,
    },
];
const containerStyles = (0, compass_components_1.css)({
    marginTop: compass_components_1.spacing[3],
});
const contentStyles = (0, compass_components_1.css)({
    marginTop: compass_components_1.spacing[3],
    width: '50%',
    minWidth: 400,
});
const getSelectedTunnelType = (connectionStringUrl, connectionOptions) => {
    const searchParams = connectionStringUrl.typedSearchParams();
    const isUsingProxy = searchParams.get('proxyHost') ||
        searchParams.get('proxyPort') ||
        searchParams.get('proxyUsername') ||
        searchParams.get('proxyPassword');
    if (isUsingProxy) {
        return 'socks';
    }
    if (!connectionOptions ||
        !(connectionOptions === null || connectionOptions === void 0 ? void 0 : connectionOptions.sshTunnel) ||
        !Object.values(connectionOptions.sshTunnel).find(Boolean)) {
        return 'none';
    }
    const isUsingIdentity = connectionOptions.sshTunnel.identityKeyFile ||
        connectionOptions.sshTunnel.identityKeyPassphrase;
    if (isUsingIdentity) {
        return 'ssh-identity';
    }
    return 'ssh-password';
};
function ProxyAndSshTunnelTab({ connectionOptions, updateConnectionFormField, errors, connectionStringUrl, }) {
    var _a;
    const selectedTunnelType = getSelectedTunnelType(connectionStringUrl, connectionOptions);
    const selectedOptionIndex = (_a = options.findIndex((x) => x.type === selectedTunnelType)) !== null && _a !== void 0 ? _a : 0;
    const [selectedOption, setSelectedOption] = (0, react_1.useState)(options[selectedOptionIndex]);
    const handleOptionChanged = (0, react_1.useCallback)((oldType, newType) => {
        let type;
        switch (newType) {
            case 'socks':
                type = 'remove-ssh-options';
                break;
            case 'ssh-identity':
            case 'ssh-password':
                type = 'remove-proxy-options';
                break;
            default:
                type =
                    oldType === 'socks' ? 'remove-proxy-options' : 'remove-ssh-options';
                break;
        }
        updateConnectionFormField({ type });
    }, [updateConnectionFormField]);
    const optionSelected = (0, react_1.useCallback)((event) => {
        event.preventDefault();
        const item = options.find(({ id }) => id === event.target.value);
        if (item) {
            handleOptionChanged(selectedOption.type, item.type);
            setSelectedOption(item);
        }
    }, [selectedOption, handleOptionChanged]);
    const TunnelContent = selectedOption.component;
    return (react_1.default.createElement("div", { className: containerStyles },
        react_1.default.createElement(compass_components_1.Label, { htmlFor: "ssh-options-radio-box-group" }, "SSH Tunnel/Proxy Method"),
        react_1.default.createElement(compass_components_1.RadioBoxGroup, { onChange: optionSelected, className: "radio-box-group-style" }, options.map(({ title, id, type }) => {
            return (react_1.default.createElement(compass_components_1.RadioBox, { "data-testid": `${type}-tab-button`, checked: selectedOption.id === id, value: id, key: id }, title));
        })),
        connectionOptions && (react_1.default.createElement("div", { className: contentStyles, "data-testid": `${selectedOption.type}-tab-content` },
            react_1.default.createElement(TunnelContent, { errors: errors, sshTunnelOptions: connectionOptions.sshTunnel, updateConnectionFormField: updateConnectionFormField, connectionStringUrl: connectionStringUrl })))));
}
exports.default = ProxyAndSshTunnelTab;
//# sourceMappingURL=proxy-and-ssh-tunnel-tab.js.map