"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTLSOptionForConnectionString = void 0;
const react_1 = __importStar(require("react"));
const compass_components_1 = require("@mongodb-js/compass-components");
const form_field_container_1 = __importDefault(require("../../form-field-container"));
const tls_client_certificate_1 = __importDefault(require("./tls-client-certificate"));
const tls_certificate_authority_1 = __importDefault(require("./tls-certificate-authority"));
const infoButtonStyles = (0, compass_components_1.css)({
    verticalAlign: 'middle',
    marginTop: -compass_components_1.spacing[2],
    marginBottom: -compass_components_1.spacing[2],
});
const disabledCheckboxDescriptionStyles = (0, compass_components_1.css)({
    color: compass_components_1.uiColors.gray.light1,
});
const TLS_TYPES = [
    {
        value: 'DEFAULT',
        label: 'Default',
    },
    {
        value: 'ON',
        label: 'On',
    },
    {
        value: 'OFF',
        label: 'Off',
    },
];
function getTLSOptionForConnectionString(connectionStringUrl) {
    const searchParams = connectionStringUrl.typedSearchParams();
    if (searchParams.get('ssl') === null && searchParams.get('tls') === null) {
        return 'DEFAULT';
    }
    if (searchParams.get('tls') === 'true' &&
        (searchParams.get('ssl') === null || searchParams.get('ssl') === 'true')) {
        return 'ON';
    }
    if (searchParams.get('tls') === 'false' &&
        (searchParams.get('ssl') === null || searchParams.get('ssl') === 'false')) {
        return 'OFF';
    }
    if (searchParams.get('ssl') === 'true' && searchParams.get('tls') === null) {
        return 'ON';
    }
    if (searchParams.get('ssl') === 'false' && searchParams.get('tls') === null) {
        return 'OFF';
    }
}
exports.getTLSOptionForConnectionString = getTLSOptionForConnectionString;
function TLSTab({ connectionStringUrl, updateConnectionFormField, }) {
    const tlsOption = getTLSOptionForConnectionString(connectionStringUrl);
    const onChangeTLS = (0, react_1.useCallback)((event) => {
        updateConnectionFormField({
            type: 'update-tls',
            tlsOption: event.target.value,
        });
    }, [updateConnectionFormField]);
    const tlsOptionFields = [
        {
            name: 'tlsInsecure',
            description: 'This includes tlsAllowInvalidHostnames and tlsAllowInvalidCertificates.',
            checked: connectionStringUrl.searchParams.get('tlsInsecure') === 'true',
        },
        {
            name: 'tlsAllowInvalidHostnames',
            description: 'Disable the validation of the hostnames in the certificate presented by the mongod/mongos instance.',
            checked: connectionStringUrl.searchParams.get('tlsAllowInvalidHostnames') ===
                'true',
        },
        {
            name: 'tlsAllowInvalidCertificates',
            description: 'Disable the validation of the server certificates.',
            checked: connectionStringUrl.searchParams.get('tlsAllowInvalidCertificates') ===
                'true',
        },
    ];
    const tlsOptionsDisabled = tlsOption === 'OFF';
    const handleTlsOptionChanged = (0, react_1.useCallback)((key, value) => {
        return updateConnectionFormField({
            type: 'update-tls-option',
            key,
            value,
        });
    }, [updateConnectionFormField]);
    return (react_1.default.createElement("div", null,
        react_1.default.createElement(form_field_container_1.default, null,
            react_1.default.createElement(compass_components_1.Label, { htmlFor: "connection-schema-radio-box-group" },
                "SSL/TLS Connection",
                react_1.default.createElement(compass_components_1.IconButton, { className: infoButtonStyles, "aria-label": "TLS/SSL Option Documentation", href: "https://docs.mongodb.com/manual/reference/connection-string/#tls-options", target: "_blank" },
                    react_1.default.createElement(compass_components_1.Icon, { glyph: "InfoWithCircle", size: "small" }))),
            react_1.default.createElement(compass_components_1.RadioBoxGroup, { value: tlsOption || '', onChange: onChangeTLS }, TLS_TYPES.map((tlsType) => (react_1.default.createElement(compass_components_1.RadioBox, { value: tlsType.value, key: tlsType.value }, tlsType.label))))),
        react_1.default.createElement(tls_certificate_authority_1.default, { connectionStringUrl: connectionStringUrl, disabled: tlsOptionsDisabled, updateCAFile: (newCertificatePath) => {
                handleTlsOptionChanged('tlsCAFile', newCertificatePath);
            } }),
        react_1.default.createElement(tls_client_certificate_1.default, { connectionStringUrl: connectionStringUrl, disabled: tlsOptionsDisabled, updateTLSClientCertificate: (newCertificatePath) => {
                handleTlsOptionChanged('tlsCertificateKeyFile', newCertificatePath);
            }, updateTLSClientCertificatePassword: (newCertificatePath) => {
                handleTlsOptionChanged('tlsCertificateKeyFilePassword', newCertificatePath);
            } }),
        tlsOptionFields.map((tlsOptionField) => (react_1.default.createElement(form_field_container_1.default, { key: tlsOptionField.name },
            react_1.default.createElement(compass_components_1.Checkbox, { onChange: (event) => {
                    handleTlsOptionChanged(tlsOptionField.name, event.target.checked ? 'true' : null);
                }, "data-testid": `${tlsOptionField.name}-input`, label: tlsOptionField.name, disabled: tlsOptionsDisabled, checked: tlsOptionField.checked, bold: false }),
            react_1.default.createElement(compass_components_1.Description, { className: (0, compass_components_1.cx)({
                    [disabledCheckboxDescriptionStyles]: tlsOptionsDisabled,
                }) }, tlsOptionField.description))))));
}
exports.default = TLSTab;
//# sourceMappingURL=tls-ssl-tab.js.map