"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.hidePasswordInConnectionString = void 0;
const react_1 = __importStar(require("react"));
const compass_components_1 = require("@mongodb-js/compass-components");
const mongodb_connection_string_url_1 = require("mongodb-connection-string-url");
const confirm_edit_connection_string_1 = __importDefault(require("./confirm-edit-connection-string"));
const uriLabelStyles = (0, compass_components_1.css)({
    padding: 0,
    margin: 0,
    flexGrow: 1,
});
const infoButtonStyles = (0, compass_components_1.css)({
    verticalAlign: 'middle',
    marginTop: -compass_components_1.spacing[1],
});
const textAreaContainerStyle = (0, compass_components_1.css)({
    position: 'relative',
    marginBottom: compass_components_1.spacing[2],
});
const connectionStringStyles = (0, compass_components_1.css)({
    textarea: {
        minHeight: compass_components_1.spacing[7],
        resize: 'vertical',
    },
});
const editToggleStyles = (0, compass_components_1.css)({
    height: 14,
    width: 26,
    margin: compass_components_1.spacing[1],
    marginRight: 0,
});
const editToggleLabelStyles = (0, compass_components_1.css)({
    '&:hover': {
        cursor: 'pointer',
    },
});
const textAreaLabelContainerStyles = (0, compass_components_1.css)({
    marginTop: compass_components_1.spacing[3],
    display: 'flex',
    flexDirection: 'row',
});
const connectionStringInputId = 'connectionString';
const connectionStringLabelId = 'connectionStringLabel';
function hidePasswordInConnectionString(connectionString) {
    return (0, mongodb_connection_string_url_1.redactConnectionString)(connectionString, {
        redactUsernames: false,
        replacementString: '*****',
    });
}
exports.hidePasswordInConnectionString = hidePasswordInConnectionString;
function ConnectStringInput({ connectionString, enableEditingConnectionString, setEnableEditingConnectionString, updateConnectionFormField, }) {
    const textAreaEl = (0, react_1.useRef)(null);
    const [editingConnectionString, setEditingConnectionString] = (0, react_1.useState)(connectionString);
    const [showEditConnectionStringPrompt, setShowEditConnectionStringPrompt] = (0, react_1.useState)(false);
    (0, react_1.useEffect)(() => {
        if (editingConnectionString !== connectionString &&
            (!textAreaEl.current || textAreaEl.current !== document.activeElement)) {
            setEditingConnectionString(connectionString);
        }
    }, [
        connectionString,
        enableEditingConnectionString,
        editingConnectionString,
    ]);
    const onChangeConnectionString = (0, react_1.useCallback)((event) => {
        const newConnectionString = event.target.value;
        setEditingConnectionString(newConnectionString);
        updateConnectionFormField({
            type: 'update-connection-string',
            newConnectionStringValue: newConnectionString,
        });
    }, [updateConnectionFormField]);
    const displayedConnectionString = enableEditingConnectionString
        ? editingConnectionString
        : hidePasswordInConnectionString(editingConnectionString);
    return (react_1.default.createElement(react_1.Fragment, null,
        react_1.default.createElement("div", { className: textAreaLabelContainerStyles },
            react_1.default.createElement(compass_components_1.Label, { className: uriLabelStyles, htmlFor: connectionStringInputId, id: connectionStringLabelId },
                "URI",
                react_1.default.createElement(compass_components_1.IconButton, { className: infoButtonStyles, "aria-label": "Connection String Documentation", "data-testid": "connectionStringDocsButton", href: "https://docs.mongodb.com/manual/reference/connection-string/", target: "_blank" },
                    react_1.default.createElement(compass_components_1.Icon, { glyph: "InfoWithCircle", size: "small" }))),
            react_1.default.createElement("label", { className: editToggleLabelStyles, id: "edit-connection-string-label", htmlFor: "toggle-edit-connection-string" }, "Edit Connection String"),
            react_1.default.createElement(compass_components_1.Toggle, { className: editToggleStyles, id: "toggle-edit-connection-string", "aria-labelledby": "edit-connection-string-label", size: "xsmall", checked: enableEditingConnectionString, onChange: (checked) => {
                    if (checked) {
                        setShowEditConnectionStringPrompt(true);
                        return;
                    }
                    setEnableEditingConnectionString(false);
                } })),
        react_1.default.createElement("div", { className: textAreaContainerStyle },
            react_1.default.createElement(compass_components_1.TextArea, { onChange: onChangeConnectionString, value: displayedConnectionString, className: connectionStringStyles, disabled: !enableEditingConnectionString, id: connectionStringInputId, ref: textAreaEl, "aria-labelledby": connectionStringLabelId, placeholder: "e.g mongodb+srv://username:password@cluster0-jtpxd.mongodb.net/admin", spellCheck: false }),
            react_1.default.createElement(confirm_edit_connection_string_1.default, { open: showEditConnectionStringPrompt, onCancel: () => {
                    setShowEditConnectionStringPrompt(false);
                }, onConfirm: () => {
                    setEnableEditingConnectionString(true);
                    setShowEditConnectionStringPrompt(false);
                } }))));
}
exports.default = ConnectStringInput;
//# sourceMappingURL=connection-string-input.js.map