"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const compass_components_1 = require("@mongodb-js/compass-components");
const COLORS = [
    '#5fc86e',
    '#326fde',
    '#deb342',
    '#d4366e',
    '#59c1e2',
    '#2c5f4a',
    '#d66531',
    '#773819',
    '#3b8196',
    '#ababab',
];
const colorOptionStyles = (0, compass_components_1.css)({
    outline: 'none',
    margin: 0,
    padding: 0,
    marginRight: compass_components_1.spacing[2],
    borderRadius: '50%',
    verticalAlign: 'middle',
    width: 36,
    height: 36,
    border: '1px solid transparent',
    boxShadow: `0 0 0 0 ${compass_components_1.uiColors.focus}`,
    transition: 'box-shadow .16s ease-in',
    position: 'relative',
    overflow: 'hidden',
});
const activeColorOptionStyles = (0, compass_components_1.css)({
    boxShadow: `0 0 0 3px ${compass_components_1.uiColors.focus}`,
    transitionTimingFunction: 'ease-out',
});
const inActiveColorOptionStyles = (0, compass_components_1.css)({
    '&:focus, &:hover': {
        boxShadow: `0 0 0 3px ${compass_components_1.uiColors.gray.light1}`,
    },
});
const noColorRedBarStyles = (0, compass_components_1.css)({
    width: 40,
    borderTop: `3px solid ${compass_components_1.uiColors.red.base}`,
    transform: 'rotate(-45deg)',
    position: 'absolute',
    left: -5,
});
const selectedColorCheckmarkStyles = (0, compass_components_1.css)({
    margin: 0,
    padding: 0,
});
function ColorOption({ isSelected, onClick, hex, }) {
    return (react_1.default.createElement("button", { style: { background: hex }, className: (0, compass_components_1.cx)({
            [colorOptionStyles]: true,
            [activeColorOptionStyles]: isSelected,
            [inActiveColorOptionStyles]: !isSelected,
        }), "data-testid": `color-pick-${hex}${isSelected ? '-selected' : ''}`, onClick: onClick, title: hex, "aria-pressed": isSelected }, isSelected && (react_1.default.createElement("svg", { className: selectedColorCheckmarkStyles, xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 24 24", width: 20, height: 34 },
        react_1.default.createElement("g", { fill: "white", fillOpacity: isSelected ? 1 : 0, strokeOpacity: isSelected ? 1 : 0 },
            react_1.default.createElement("path", { stroke: "#ffffff", d: "M21,7L9,19L3.5,13.5L4.91,12.09L9,16.17L19.59,5.59L21,7Z" }))))));
}
function SavedConnectionColorPicker({ hex, onChange, }) {
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(compass_components_1.Label, { htmlFor: "favorite-color-selector" }, "Color"),
        react_1.default.createElement("div", { id: "favorite-color-selector" },
            react_1.default.createElement("button", { style: {
                    background: 'white',
                    borderColor: compass_components_1.uiColors.black,
                }, className: (0, compass_components_1.cx)({
                    [colorOptionStyles]: true,
                    [activeColorOptionStyles]: !hex,
                }), onClick: () => {
                    onChange();
                }, "data-testid": `color-pick-no-color${!hex ? '-selected' : ''}`, title: "No color", "aria-pressed": !hex },
                react_1.default.createElement("div", { className: noColorRedBarStyles })),
            COLORS.map((color) => (react_1.default.createElement(ColorOption, { onClick: () => {
                    onChange(color);
                }, isSelected: color === hex, hex: color, key: color }))))));
}
exports.default = SavedConnectionColorPicker;
//# sourceMappingURL=saved-connection-color-picker.js.map