"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WarningSummary = exports.ErrorSummary = void 0;
const react_1 = __importDefault(require("react"));
const compass_components_1 = require("@mongodb-js/compass-components");
const bannerStyle = (0, compass_components_1.css)({
    marginTop: compass_components_1.spacing[1],
});
const listStyle = (0, compass_components_1.css)({
    padding: 0,
    margin: 0,
    listStylePosition: 'inside',
});
function ErrorSummary({ errors, }) {
    if (!errors || !errors.length)
        return null;
    return (react_1.default.createElement(compass_components_1.Banner, { variant: compass_components_1.BannerVariant.Danger, className: bannerStyle },
        react_1.default.createElement(Summary, { messages: errors.map((err) => err.message) })));
}
exports.ErrorSummary = ErrorSummary;
function WarningSummary({ warnings, }) {
    if (!warnings || !warnings.length)
        return null;
    return (react_1.default.createElement(compass_components_1.Banner, { variant: compass_components_1.BannerVariant.Warning, className: bannerStyle },
        react_1.default.createElement(Summary, { messages: warnings.map((warning) => warning.message) })));
}
exports.WarningSummary = WarningSummary;
function Summary({ messages }) {
    if (messages.length === 1) {
        return react_1.default.createElement("div", null, messages[0]);
    }
    if (messages.length === 2) {
        return (react_1.default.createElement("div", null,
            react_1.default.createElement("ol", { className: listStyle }, messages.map((message, i) => (react_1.default.createElement("li", { key: i }, message))))));
    }
    const tooltipErrors = (react_1.default.createElement("ol", { className: listStyle }, messages.map((message, i) => (react_1.default.createElement("li", { key: i }, message)))));
    const firstMessageNoDot = messages[0].endsWith('.')
        ? messages[0].slice(0, messages[0].length - 1)
        : messages[0];
    return (react_1.default.createElement("div", null,
        react_1.default.createElement("span", null,
            firstMessageNoDot,
            ", and other ",
            messages.length - 1,
            " problems."),
        ' ',
        react_1.default.createElement(compass_components_1.InlineDefinition, { tooltipProps: {
                align: 'top',
                justify: 'start',
                delay: 500,
            }, definition: tooltipErrors }, "View all")));
}
//# sourceMappingURL=validation-summary.js.map