import type { ConnectionInfo, ConnectionOptions } from 'mongodb-data-service';
import type { MongoClientOptions } from 'mongodb';
import type { ConnectionFormError, ConnectionFormWarning } from '../utils/validation';
import type { UpdateSshOptions } from '../utils/connection-ssh-handler';
import type { UpdateTlsAction, UpdateTlsOptionAction } from '../utils/tls-handler';
import type { UpdateAuthMechanismAction, UpdatePasswordAction, UpdateUsernameAction } from '../utils/authentication-handler';
import type { AuthMechanismProperties } from '../utils/connection-string-helpers';
export interface ConnectFormState {
    connectionOptions: ConnectionOptions;
    enableEditingConnectionString: boolean;
    errors: ConnectionFormError[];
    warnings: ConnectionFormWarning[];
}
interface UpdateConnectionStringAction {
    type: 'update-connection-string';
    newConnectionStringValue: string;
}
interface UpdateHostAction {
    type: 'update-host';
    fieldIndex: number;
    newHostValue: string;
}
declare type ConnectionFormFieldActions = UpdateConnectionStringAction | {
    type: 'add-new-host';
    fieldIndexToAddAfter: number;
} | {
    type: 'remove-host';
    fieldIndexToRemove: number;
} | UpdateUsernameAction | UpdatePasswordAction | UpdateAuthMechanismAction | UpdateHostAction | {
    type: 'update-connection-schema';
    isSrv: boolean;
} | UpdateSshOptions | UpdateTlsAction | UpdateTlsOptionAction | {
    type: 'update-search-param';
    currentKey: keyof MongoClientOptions;
    newKey?: keyof MongoClientOptions;
    value?: string;
} | {
    type: 'delete-search-param';
    key: keyof MongoClientOptions;
} | {
    type: 'update-auth-mechanism-property';
    key: keyof AuthMechanismProperties;
    value?: string;
} | {
    type: 'update-connection-path';
    value: string;
} | {
    type: 'remove-ssh-options';
} | {
    type: 'remove-proxy-options';
};
export declare type UpdateConnectionFormField = (action: ConnectionFormFieldActions) => void;
export declare function handleConnectionFormFieldUpdate(action: ConnectionFormFieldActions, currentConnectionOptions: ConnectionOptions): {
    connectionOptions: ConnectionOptions;
    errors?: ConnectionFormError[];
};
export declare function useConnectForm(initialConnectionInfo: ConnectionInfo, connectionErrorMessage?: string | null): [
    ConnectFormState,
    {
        updateConnectionFormField: UpdateConnectionFormField;
        setErrors: (errors: ConnectionFormError[]) => void;
        setEnableEditingConnectionString: (enableEditing: boolean) => void;
    }
];
export {};
//# sourceMappingURL=use-connect-form.d.ts.map