"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleUpdatePassword = exports.handleUpdateUsername = exports.handleUpdateAuthMechanism = exports.getConnectionUrlWithoutAuth = void 0;
const connection_string_helpers_1 = require("./connection-string-helpers");
function getConnectionUrlWithoutAuth(connectionStringUrl) {
    const updatedConnectionString = connectionStringUrl.clone();
    const updatedSearchParams = updatedConnectionString.typedSearchParams();
    updatedSearchParams.delete('authMechanism');
    updatedConnectionString.password = '';
    updatedConnectionString.username = '';
    updatedSearchParams.delete('authMechanismProperties');
    updatedSearchParams.delete('gssapiServiceName');
    updatedSearchParams.delete('authSource');
    return updatedConnectionString;
}
exports.getConnectionUrlWithoutAuth = getConnectionUrlWithoutAuth;
function handleUpdateAuthMechanism({ action, connectionStringUrl, connectionOptions, }) {
    const updatedConnectionString = getConnectionUrlWithoutAuth(connectionStringUrl);
    const updatedSearchParams = updatedConnectionString.typedSearchParams();
    if (action.authMechanism) {
        updatedSearchParams.set('authMechanism', action.authMechanism);
        if (['MONGODB-AWS', 'GSSAPI', 'PLAIN', 'MONGODB-X509'].includes(action.authMechanism)) {
            updatedSearchParams.set('authSource', '$external');
        }
    }
    return {
        connectionOptions: {
            ...connectionOptions,
            connectionString: updatedConnectionString.toString(),
        },
    };
}
exports.handleUpdateAuthMechanism = handleUpdateAuthMechanism;
function handleUpdateUsername({ action, connectionStringUrl, connectionOptions, }) {
    const updatedConnectionString = (0, connection_string_helpers_1.setConnectionStringUsername)(connectionStringUrl, action.username);
    const [, parsingError] = (0, connection_string_helpers_1.tryToParseConnectionString)(updatedConnectionString.toString());
    if (parsingError) {
        return {
            connectionOptions,
            errors: [
                {
                    fieldName: 'username',
                    fieldTab: 'authentication',
                    message: action.username
                        ? parsingError.message
                        : `Username cannot be empty: "${parsingError.message}"`,
                },
            ],
        };
    }
    return {
        connectionOptions: {
            ...connectionOptions,
            connectionString: updatedConnectionString.toString(),
        },
    };
}
exports.handleUpdateUsername = handleUpdateUsername;
function handleUpdatePassword({ action, connectionStringUrl, connectionOptions, }) {
    const updatedConnectionString = (0, connection_string_helpers_1.setConnectionStringPassword)(connectionStringUrl, action.password);
    const [, parsingError] = (0, connection_string_helpers_1.tryToParseConnectionString)(updatedConnectionString.toString());
    if (parsingError) {
        return {
            connectionOptions,
            errors: connectionStringUrl.username
                ? [
                    {
                        fieldName: 'password',
                        fieldTab: 'authentication',
                        message: parsingError.message,
                    },
                ]
                : [
                    {
                        fieldName: 'username',
                        fieldTab: 'authentication',
                        message: `Username cannot be empty: "${parsingError.message}"`,
                    },
                    {
                        fieldName: 'password',
                        fieldTab: 'authentication',
                        message: 'Please enter a username first',
                    },
                ],
        };
    }
    return {
        connectionOptions: {
            ...connectionOptions,
            connectionString: updatedConnectionString.toString(),
        },
    };
}
exports.handleUpdatePassword = handleUpdatePassword;
//# sourceMappingURL=authentication-handler.js.map